@@ -20,7 +20,7 @@ double Fl_Spinner_minimum(Fl_Spinner *self) {
 }
 
 void Fl_Spinner_set_minimum(Fl_Spinner *self, double a) {
-    LOCK(self->minimum(a);)
+    LOCK(self->minimum(a));
 }
 
 double Fl_Spinner_maximum(Fl_Spinner *self) {
@@ -28,15 +28,15 @@ double Fl_Spinner_maximum(Fl_Spinner *self) {
 }
 
 void Fl_Spinner_set_maximum(Fl_Spinner *self, double a) {
-    LOCK(self->maximum(a);)
+    LOCK(self->maximum(a));
 }
 
 void Fl_Spinner_set_range(Fl_Spinner *self, double a, double b) {
-    LOCK(self->range(a, b);)
+    LOCK(self->range(a, b));
 }
 
 void Fl_Spinner_set_step(Fl_Spinner *self, double a) {
-    LOCK(self->step(a);)
+    LOCK(self->step(a));
 }
 
 double Fl_Spinner_step(Fl_Spinner *self) {
@@ -48,7 +48,7 @@ int Fl_Spinner_maxsize(const Fl_Spinner *self) {
 }
 
 void Fl_Spinner_set_maxsize(Fl_Spinner *self, int m) {
-    LOCK(self->maximum_size(m);)
+    LOCK(self->maximum_size(m));
 }
 
 int Fl_Spinner_text_font(const Fl_Spinner *self) {
@@ -56,7 +56,7 @@ int Fl_Spinner_text_font(const Fl_Spinner *self) {
 }
 
 void Fl_Spinner_set_text_font(Fl_Spinner *self, int s) {
-    LOCK(self->textfont(s);)
+    LOCK(self->textfont(s));
 }
 
 int Fl_Spinner_text_size(const Fl_Spinner *self) {
@@ -64,7 +64,7 @@ int Fl_Spinner_text_size(const Fl_Spinner *self) {
 }
 
 void Fl_Spinner_set_text_size(Fl_Spinner *self, int s) {
-    LOCK(self->textsize(s);)
+    LOCK(self->textsize(s));
 }
 
 unsigned int Fl_Spinner_text_color(const Fl_Spinner *self) {
@@ -72,7 +72,7 @@ unsigned int Fl_Spinner_text_color(const Fl_Spinner *self) {
 }
 
 void Fl_Spinner_set_text_color(Fl_Spinner *self, unsigned int n) {
-    LOCK(self->textcolor(n);)
+    LOCK(self->textcolor(n));
 }
 
 double Fl_Spinner_value(const Fl_Spinner *self) {
@@ -80,7 +80,7 @@ double Fl_Spinner_value(const Fl_Spinner *self) {
 }
 
 void Fl_Spinner_set_value(Fl_Spinner *self, double val) {
-    LOCK(self->value(val);)
+    LOCK(self->value(val));
 }
 
 WIDGET_CLASS(Fl_Clock)
@@ -92,23 +92,23 @@ WIDGET_CLASS(Fl_Chart)
 WIDGET_DEFINE(Fl_Chart)
 
 void Fl_Chart_clear(Fl_Chart *self) {
-    LOCK(self->clear();)
+    LOCK(self->clear());
 }
 
 void Fl_Chart_add(Fl_Chart *self, double val, const char *str, unsigned col) {
-    LOCK(self->add(val, str, col);)
+    LOCK(self->add(val, str, col));
 }
 
 void Fl_Chart_insert(Fl_Chart *self, int ind, double val, const char *str, unsigned col) {
-    LOCK(self->insert(ind, val, str, col);)
+    LOCK(self->insert(ind, val, str, col));
 }
 
 void Fl_Chart_replace(Fl_Chart *self, int ind, double val, const char *str, unsigned col) {
-    LOCK(self->replace(ind, val, str, col);)
+    LOCK(self->replace(ind, val, str, col));
 }
 
 void Fl_Chart_set_bounds(Fl_Chart *self, double a, double b) {
-    LOCK(self->bounds(a, b);)
+    LOCK(self->bounds(a, b));
 }
 
 int Fl_Chart_size(const Fl_Chart *self) {
@@ -120,7 +120,7 @@ int Fl_Chart_maxsize(const Fl_Chart *self) {
 }
 
 void Fl_Chart_set_maxsize(Fl_Chart *self, int m) {
-    LOCK(self->maxsize(m);)
+    LOCK(self->maxsize(m));
 }
 
 int Fl_Chart_text_font(const Fl_Chart *self) {
@@ -128,7 +128,7 @@ int Fl_Chart_text_font(const Fl_Chart *self) {
 }
 
 void Fl_Chart_set_text_font(Fl_Chart *self, int s) {
-    LOCK(self->textfont(s);)
+    LOCK(self->textfont(s));
 }
 
 int Fl_Chart_text_size(const Fl_Chart *self) {
@@ -136,7 +136,7 @@ int Fl_Chart_text_size(const Fl_Chart *self) {
 }
 
 void Fl_Chart_set_text_size(Fl_Chart *self, int s) {
-    LOCK(self->textsize(s);)
+    LOCK(self->textsize(s));
 }
 
 unsigned int Fl_Chart_text_color(const Fl_Chart *self) {
@@ -144,7 +144,7 @@ unsigned int Fl_Chart_text_color(const Fl_Chart *self) {
 }
 
 void Fl_Chart_set_text_color(Fl_Chart *self, unsigned int n) {
-    LOCK(self->textcolor(n);)
+    LOCK(self->textcolor(n));
 }
 
 int Fl_Chart_is_autosize(const Fl_Chart *self) {
@@ -152,7 +152,7 @@ int Fl_Chart_is_autosize(const Fl_Chart *self) {
 }
 
 void Fl_Chart_make_autosize(Fl_Chart *self, int n) {
-    LOCK(self->autosize(n);)
+    LOCK(self->autosize(n));
 }
 
 WIDGET_CLASS(Fl_Progress)
@@ -164,7 +164,7 @@ double Fl_Progress_minimum(Fl_Progress *self) {
 }
 
 void Fl_Progress_set_minimum(Fl_Progress *self, double a) {
-    LOCK(self->minimum(a);)
+    LOCK(self->minimum(a));
 }
 
 double Fl_Progress_maximum(Fl_Progress *self) {
@@ -172,7 +172,7 @@ double Fl_Progress_maximum(Fl_Progress *self) {
 }
 
 void Fl_Progress_set_maximum(Fl_Progress *self, double a) {
-    LOCK(self->maximum(a);)
+    LOCK(self->maximum(a));
 }
 
 double Fl_Progress_value(Fl_Progress *self) {
@@ -180,7 +180,7 @@ double Fl_Progress_value(Fl_Progress *self) {
 }
 
 void Fl_Progress_set_value(Fl_Progress *self, double val) {
-    LOCK(self->value(val);)
+    LOCK(self->value(val));
 }
 
 float Fl_Tooltip_delay(void) {
@@ -188,7 +188,7 @@ float Fl_Tooltip_delay(void) {
 }
 
 void Fl_Tooltip_set_delay(float f) {
-    LOCK(Fl_Tooltip::delay(f);)
+    LOCK(Fl_Tooltip::delay(f));
 }
 
 float Fl_Tooltip_hidedelay(void) {
@@ -196,7 +196,7 @@ float Fl_Tooltip_hidedelay(void) {
 }
 
 void Fl_Tooltip_set_hidedelay(float f) {
-    LOCK(Fl_Tooltip::hidedelay(f);)
+    LOCK(Fl_Tooltip::hidedelay(f));
 }
 
 float Fl_Tooltip_hoverdelay(void) {
@@ -204,7 +204,7 @@ float Fl_Tooltip_hoverdelay(void) {
 }
 
 void Fl_Tooltip_set_hoverdelay(float f) {
-    LOCK(Fl_Tooltip::hoverdelay(f);)
+    LOCK(Fl_Tooltip::hoverdelay(f));
 }
 
 int Fl_Tooltip_enabled(void) {
@@ -212,15 +212,15 @@ int Fl_Tooltip_enabled(void) {
 }
 
 void Fl_Tooltip_enable(int b) {
-    LOCK(Fl_Tooltip::enable(b);)
+    LOCK(Fl_Tooltip::enable(b));
 }
 
 void Fl_Tooltip_disable(void) {
-    LOCK(Fl_Tooltip::disable();)
+    LOCK(Fl_Tooltip::disable());
 }
 
 void Fl_Tooltip_enter_area(Fl_Widget *w, int X, int Y, int W, int H, const char *tip) {
-    LOCK(Fl_Tooltip::enter_area(w, X, Y, W, H, tip);)
+    LOCK(Fl_Tooltip::enter_area(w, X, Y, W, H, tip));
 }
 
 void *Fl_Tooltip_current_widget(void) {
@@ -228,7 +228,7 @@ void *Fl_Tooltip_current_widget(void) {
 }
 
 void Fl_Tooltip_set_current_widget(Fl_Widget *w) {
-    LOCK(Fl_Tooltip::current(w);)
+    LOCK(Fl_Tooltip::current(w));
 }
 
 int Fl_Tooltip_font(void) {
@@ -236,7 +236,7 @@ int Fl_Tooltip_font(void) {
 }
 
 void Fl_Tooltip_set_font(int i) {
-    LOCK(Fl_Tooltip::font(i);)
+    LOCK(Fl_Tooltip::font(i));
 }
 
 int Fl_Tooltip_font_size(void) {
@@ -244,7 +244,7 @@ int Fl_Tooltip_font_size(void) {
 }
 
 void Fl_Tooltip_set_font_size(int s) {
-    LOCK(Fl_Tooltip::size(s);)
+    LOCK(Fl_Tooltip::size(s));
 }
 
 int Fl_Tooltip_color(void) {
@@ -252,7 +252,7 @@ int Fl_Tooltip_color(void) {
 }
 
 void Fl_Tooltip_set_color(unsigned int c) {
-    LOCK(Fl_Tooltip::color(c);)
+    LOCK(Fl_Tooltip::color(c));
 }
 
 int Fl_Tooltip_text_color(void) {
@@ -260,7 +260,7 @@ int Fl_Tooltip_text_color(void) {
 }
 
 void Fl_Tooltip_set_text_color(unsigned int c) {
-    LOCK(Fl_Tooltip::textcolor(c);)
+    LOCK(Fl_Tooltip::textcolor(c));
 }
 
 int Fl_Tooltip_margin_width(void) {
@@ -268,7 +268,7 @@ int Fl_Tooltip_margin_width(void) {
 }
 
 void Fl_Tooltip_set_margin_width(int v) {
-    LOCK(Fl_Tooltip::margin_width(v);)
+    LOCK(Fl_Tooltip::margin_width(v));
 }
 
 int Fl_Tooltip_margin_height(void) {
@@ -276,7 +276,7 @@ int Fl_Tooltip_margin_height(void) {
 }
 
 void Fl_Tooltip_set_margin_height(int v) {
-    LOCK(Fl_Tooltip::margin_height(v);)
+    LOCK(Fl_Tooltip::margin_height(v));
 }
 
 int Fl_Tooltip_wrap_width(void) {
@@ -284,7 +284,7 @@ int Fl_Tooltip_wrap_width(void) {
 }
 
 void Fl_Tooltip_set_wrap_width(int v) {
-    LOCK(Fl_Tooltip::wrap_width(v);)
+    LOCK(Fl_Tooltip::wrap_width(v));
 }
 
 void *Fl_Tooltip_current_window(void) {
